==> anwiba-spatial-data-ckan-1.0.76-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Dataset.java <==
//Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Dataset {

    private String license_title = null;
    private String maintainer = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_object = null;
    private String issued = null;
    private Boolean _private = Boolean.valueOf(false);
    private String maintainer_email = null;
    private Integer num_tags = Integer.valueOf(0);
    private String id = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.DateString metadata_created = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.DateString metadata_modified = null;
    private Label[] conforms_to = null;
    private String author = null;
    private String author_email = null;
    private String state = null;
    private String version = null;
    private String creator_user_id = null;
    private String type = null;
    private Resource[] resources = null;
    private Integer num_resources = Integer.valueOf(0);
    private Tag[] tags = null;
    private Group[] groups = null;
    private String license_id = null;
    private Translation translation = null;
    private TranslationMetadata translation_meta = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_subject = null;
    private Organization organization = null;
    private String name = null;
    private Boolean isopen = Boolean.valueOf(false);
    private String url = null;
    private String notes = null;
    private String owner_org = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.DateString modified = null;
    private Extra[] extras = null;
    private String original_source = null;
    private String license_url = null;
    private String title = null;
    private String revision_id = null;
    private String[] identifier = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("license_title")
    public void setLicense_title(final String license_title) {
        this.license_title = license_title;
    }

    @JsonProperty("license_title")
    public String getLicense_title() {
        return this.license_title;
    }

    @JsonProperty("maintainer")
    public void setMaintainer(final String maintainer) {
        this.maintainer = maintainer;
    }

    @JsonProperty("maintainer")
    public String getMaintainer() {
        return this.maintainer;
    }

    @JsonProperty("relationships_as_object")
    public void setRelationships_as_object(final net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_object) {
        this.relationships_as_object = relationships_as_object;
    }

    @JsonProperty("relationships_as_object")
    public net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] getRelationships_as_object() {
        return this.relationships_as_object;
    }

    @JsonProperty("issued")
    public void setIssued(final String issued) {
        this.issued = issued;
    }

    @JsonProperty("issued")
    public String getIssued() {
        return this.issued;
    }

    @JsonProperty("private")
    public void setPrivate(final Boolean _private) {
        this._private = _private;
    }

    @JsonProperty("private")
    public Boolean isPrivate() {
        return this._private;
    }

    @JsonProperty("maintainer_email")
    public void setMaintainer_email(final String maintainer_email) {
        this.maintainer_email = maintainer_email;
    }

    @JsonProperty("maintainer_email")
    public String getMaintainer_email() {
        return this.maintainer_email;
    }

    @JsonProperty("num_tags")
    public void setNum_tags(final Integer num_tags) {
        this.num_tags = num_tags;
    }

    @JsonProperty("num_tags")
    public Integer getNum_tags() {
        return this.num_tags;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("metadata_created")
    public void setMetadata_created(final net.anwiba.spatial.ckan.json.schema.v1_0.DateString metadata_created) {
        this.metadata_created = metadata_created;
    }

    @JsonProperty("metadata_created")
    public net.anwiba.spatial.ckan.json.schema.v1_0.DateString getMetadata_created() {
        return this.metadata_created;
    }

    @JsonProperty("metadata_modified")
    public void setMetadata_modified(final net.anwiba.spatial.ckan.json.schema.v1_0.DateString metadata_modified) {
        this.metadata_modified = metadata_modified;
    }

    @JsonProperty("metadata_modified")
    public net.anwiba.spatial.ckan.json.schema.v1_0.DateString getMetadata_modified() {
        return this.metadata_modified;
    }

    @JsonProperty("conforms_to")
    public void setConforms_to(final Label[] conforms_to) {
        this.conforms_to = conforms_to;
    }

    @JsonProperty("conforms_to")
    public Label[] getConforms_to() {
        return this.conforms_to;
    }

    @JsonProperty("author")
    public void setAuthor(final String author) {
        this.author = author;
    }

    @JsonProperty("author")
    public String getAuthor() {
        return this.author;
    }

    @JsonProperty("author_email")
    public void setAuthor_email(final String author_email) {
        this.author_email = author_email;
    }

    @JsonProperty("author_email")
    public String getAuthor_email() {
        return this.author_email;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("version")
    public void setVersion(final String version) {
        this.version = version;
    }

    @JsonProperty("version")
    public String getVersion() {
        return this.version;
    }

    @JsonProperty("creator_user_id")
    public void setCreator_user_id(final String creator_user_id) {
        this.creator_user_id = creator_user_id;
    }

    @JsonProperty("creator_user_id")
    public String getCreator_user_id() {
        return this.creator_user_id;
    }

    @JsonProperty("type")
    public void setType(final String type) {
        this.type = type;
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("resources")
    public void setResources(final Resource[] resources) {
        this.resources = resources;
    }

    @JsonProperty("resources")
    public Resource[] getResources() {
        return this.resources;
    }

    @JsonProperty("num_resources")
    public void setNum_resources(final Integer num_resources) {
        this.num_resources = num_resources;
    }

    @JsonProperty("num_resources")
    public Integer getNum_resources() {
        return this.num_resources;
    }

    @JsonProperty("tags")
    public void setTags(final Tag[] tags) {
        this.tags = tags;
    }

    @JsonProperty("tags")
    public Tag[] getTags() {
        return this.tags;
    }

    @JsonProperty("groups")
    public void setGroups(final Group[] groups) {
        this.groups = groups;
    }

    @JsonProperty("groups")
    public Group[] getGroups() {
        return this.groups;
    }

    @JsonProperty("license_id")
    public void setLicense_id(final String license_id) {
        this.license_id = license_id;
    }

    @JsonProperty("license_id")
    public String getLicense_id() {
        return this.license_id;
    }

    @JsonProperty("translation")
    public void setTranslation(final Translation translation) {
        this.translation = translation;
    }

    @JsonProperty("translation")
    public Translation getTranslation() {
        return this.translation;
    }

    @JsonProperty("translation_meta")
    public void setTranslation_meta(final TranslationMetadata translation_meta) {
        this.translation_meta = translation_meta;
    }

    @JsonProperty("translation_meta")
    public TranslationMetadata getTranslation_meta() {
        return this.translation_meta;
    }

    @JsonProperty("relationships_as_subject")
    public void setRelationships_as_subject(final net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_subject) {
        this.relationships_as_subject = relationships_as_subject;
    }

    @JsonProperty("relationships_as_subject")
    public net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] getRelationships_as_subject() {
        return this.relationships_as_subject;
    }

    @JsonProperty("organization")
    public void setOrganization(final Organization organization) {
        this.organization = organization;
    }

    @JsonProperty("organization")
    public Organization getOrganization() {
        return this.organization;
    }

    @JsonProperty("name")
    public void setName(final String name) {
        this.name = name;
    }

    @JsonProperty("name")
    public String getName() {
        return this.name;
    }

    @JsonProperty("isopen")
    public void setIsopen(final Boolean isopen) {
        this.isopen = isopen;
    }

    @JsonProperty("isopen")
    public Boolean isopen() {
        return this.isopen;
    }

    @JsonProperty("url")
    public void setUrl(final String url) {
        this.url = url;
    }

    @JsonProperty("url")
    public String getUrl() {
        return this.url;
    }

    @JsonProperty("notes")
    public void setNotes(final String notes) {
        this.notes = notes;
    }

    @JsonProperty("notes")
    public String getNotes() {
        return this.notes;
    }

    @JsonProperty("owner_org")
    public void setOwner_org(final String owner_org) {
        this.owner_org = owner_org;
    }

    @JsonProperty("owner_org")
    public String getOwner_org() {
        return this.owner_org;
    }

    @JsonProperty("modified")
    public void setModified(final net.anwiba.spatial.ckan.json.schema.v1_0.DateString modified) {
        this.modified = modified;
    }

    @JsonProperty("modified")
    public net.anwiba.spatial.ckan.json.schema.v1_0.DateString getModified() {
        return this.modified;
    }

    @JsonProperty("extras")
    public void setExtras(final Extra[] extras) {
        this.extras = extras;
    }

    @JsonProperty("extras")
    public Extra[] getExtras() {
        return this.extras;
    }

    @JsonProperty("original_source")
    public void setOriginal_source(final String original_source) {
        this.original_source = original_source;
    }

    @JsonProperty("original_source")
    public String getOriginal_source() {
        return this.original_source;
    }

    @JsonProperty("license_url")
    public void setLicense_url(final String license_url) {
        this.license_url = license_url;
    }

    @JsonProperty("license_url")
    public String getLicense_url() {
        return this.license_url;
    }

    @JsonProperty("title")
    public void setTitle(final String title) {
        this.title = title;
    }

    @JsonProperty("title")
    public String getTitle() {
        return this.title;
    }

    @JsonProperty("revision_id")
    public void setRevision_id(final String revision_id) {
        this.revision_id = revision_id;
    }

    @JsonProperty("revision_id")
    public String getRevision_id() {
        return this.revision_id;
    }

    @JsonProperty("identifier")
    public void setIdentifier(final String[] identifier) {
        this.identifier = identifier;
    }

    @JsonProperty("identifier")
    public String[] getIdentifier() {
        return this.identifier;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}

==> anwiba-spatial-data-ckan-1.0.140-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Dataset.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Dataset
    extends Named
{

    private String license_title = null;
    private String maintainer = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_object = null;
    private String issued = null;
    private Boolean _private = Boolean.valueOf(false);
    private String maintainer_email = null;
    private Integer num_tags = Integer.valueOf(0);
    private String id = null;
    private net.anwiba.spatial.ckan.json.types.DateString metadata_created = null;
    private net.anwiba.spatial.ckan.json.types.DateString metadata_modified = null;
    private Label[] conforms_to = null;
    private String author = null;
    private String author_email = null;
    private String state = null;
    private String version = null;
    private String creator_user_id = null;
    private String type = null;
    private Resource[] resources = null;
    private Integer num_resources = Integer.valueOf(0);
    private Tag[] tags = null;
    private Group[] groups = null;
    private String license_id = null;
    private Translation translation = null;
    private TranslationMetadata translation_meta = null;
    private net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_subject = null;
    private Organization organization = null;
    private Boolean isopen = Boolean.valueOf(false);
    private String url = null;
    private String notes = null;
    private String owner_org = null;
    private net.anwiba.spatial.ckan.json.types.DateString modified = null;
    private Extra[] extras = null;
    private String original_source = null;
    private String license_url = null;
    private String revision_id = null;
    private String[] identifier = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("license_title")
    public void setLicense_title(final String license_title) {
        this.license_title = license_title;
    }

    @JsonProperty("license_title")
    public String getLicense_title() {
        return this.license_title;
    }

    @JsonProperty("maintainer")
    public void setMaintainer(final String maintainer) {
        this.maintainer = maintainer;
    }

    @JsonProperty("maintainer")
    public String getMaintainer() {
        return this.maintainer;
    }

    @JsonProperty("relationships_as_object")
    public void setRelationships_as_object(final net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_object) {
        this.relationships_as_object = relationships_as_object;
    }

    @JsonProperty("relationships_as_object")
    public net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] getRelationships_as_object() {
        return this.relationships_as_object;
    }

    @JsonProperty("issued")
    public void setIssued(final String issued) {
        this.issued = issued;
    }

    @JsonProperty("issued")
    public String getIssued() {
        return this.issued;
    }

    @JsonProperty("private")
    public void setPrivate(final Boolean _private) {
        this._private = _private;
    }

    @JsonProperty("private")
    public Boolean isPrivate() {
        return this._private;
    }

    @JsonProperty("maintainer_email")
    public void setMaintainer_email(final String maintainer_email) {
        this.maintainer_email = maintainer_email;
    }

    @JsonProperty("maintainer_email")
    public String getMaintainer_email() {
        return this.maintainer_email;
    }

    @JsonProperty("num_tags")
    public void setNum_tags(final Integer num_tags) {
        this.num_tags = num_tags;
    }

    @JsonProperty("num_tags")
    public Integer getNum_tags() {
        return this.num_tags;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("metadata_created")
    public void setMetadata_created(final net.anwiba.spatial.ckan.json.types.DateString metadata_created) {
        this.metadata_created = metadata_created;
    }

    @JsonProperty("metadata_created")
    public net.anwiba.spatial.ckan.json.types.DateString getMetadata_created() {
        return this.metadata_created;
    }

    @JsonProperty("metadata_modified")
    public void setMetadata_modified(final net.anwiba.spatial.ckan.json.types.DateString metadata_modified) {
        this.metadata_modified = metadata_modified;
    }

    @JsonProperty("metadata_modified")
    public net.anwiba.spatial.ckan.json.types.DateString getMetadata_modified() {
        return this.metadata_modified;
    }

    @JsonProperty("conforms_to")
    public void setConforms_to(final Label[] conforms_to) {
        this.conforms_to = conforms_to;
    }

    @JsonProperty("conforms_to")
    public Label[] getConforms_to() {
        return this.conforms_to;
    }

    @JsonProperty("author")
    public void setAuthor(final String author) {
        this.author = author;
    }

    @JsonProperty("author")
    public String getAuthor() {
        return this.author;
    }

    @JsonProperty("author_email")
    public void setAuthor_email(final String author_email) {
        this.author_email = author_email;
    }

    @JsonProperty("author_email")
    public String getAuthor_email() {
        return this.author_email;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("version")
    public void setVersion(final String version) {
        this.version = version;
    }

    @JsonProperty("version")
    public String getVersion() {
        return this.version;
    }

    @JsonProperty("creator_user_id")
    public void setCreator_user_id(final String creator_user_id) {
        this.creator_user_id = creator_user_id;
    }

    @JsonProperty("creator_user_id")
    public String getCreator_user_id() {
        return this.creator_user_id;
    }

    @JsonProperty("type")
    public void setType(final String type) {
        this.type = type;
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("resources")
    public void setResources(final Resource[] resources) {
        this.resources = resources;
    }

    @JsonProperty("resources")
    public Resource[] getResources() {
        return this.resources;
    }

    @JsonProperty("num_resources")
    public void setNum_resources(final Integer num_resources) {
        this.num_resources = num_resources;
    }

    @JsonProperty("num_resources")
    public Integer getNum_resources() {
        return this.num_resources;
    }

    @JsonProperty("tags")
    public void setTags(final Tag[] tags) {
        this.tags = tags;
    }

    @JsonProperty("tags")
    public Tag[] getTags() {
        return this.tags;
    }

    @JsonProperty("groups")
    public void setGroups(final Group[] groups) {
        this.groups = groups;
    }

    @JsonProperty("groups")
    public Group[] getGroups() {
        return this.groups;
    }

    @JsonProperty("license_id")
    public void setLicense_id(final String license_id) {
        this.license_id = license_id;
    }

    @JsonProperty("license_id")
    public String getLicense_id() {
        return this.license_id;
    }

    @JsonProperty("translation")
    public void setTranslation(final Translation translation) {
        this.translation = translation;
    }

    @JsonProperty("translation")
    public Translation getTranslation() {
        return this.translation;
    }

    @JsonProperty("translation_meta")
    public void setTranslation_meta(final TranslationMetadata translation_meta) {
        this.translation_meta = translation_meta;
    }

    @JsonProperty("translation_meta")
    public TranslationMetadata getTranslation_meta() {
        return this.translation_meta;
    }

    @JsonProperty("relationships_as_subject")
    public void setRelationships_as_subject(final net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] relationships_as_subject) {
        this.relationships_as_subject = relationships_as_subject;
    }

    @JsonProperty("relationships_as_subject")
    public net.anwiba.spatial.ckan.json.schema.v1_0.Relationship[] getRelationships_as_subject() {
        return this.relationships_as_subject;
    }

    @JsonProperty("organization")
    public void setOrganization(final Organization organization) {
        this.organization = organization;
    }

    @JsonProperty("organization")
    public Organization getOrganization() {
        return this.organization;
    }

    @JsonProperty("isopen")
    public void setIsopen(final Boolean isopen) {
        this.isopen = isopen;
    }

    @JsonProperty("isopen")
    public Boolean isopen() {
        return this.isopen;
    }

    @JsonProperty("url")
    public void setUrl(final String url) {
        this.url = url;
    }

    @JsonProperty("url")
    public String getUrl() {
        return this.url;
    }

    @JsonProperty("notes")
    public void setNotes(final String notes) {
        this.notes = notes;
    }

    @JsonProperty("notes")
    public String getNotes() {
        return this.notes;
    }

    @JsonProperty("owner_org")
    public void setOwner_org(final String owner_org) {
        this.owner_org = owner_org;
    }

    @JsonProperty("owner_org")
    public String getOwner_org() {
        return this.owner_org;
    }

    @JsonProperty("modified")
    public void setModified(final net.anwiba.spatial.ckan.json.types.DateString modified) {
        this.modified = modified;
    }

    @JsonProperty("modified")
    public net.anwiba.spatial.ckan.json.types.DateString getModified() {
        return this.modified;
    }

    @JsonProperty("extras")
    public void setExtras(final Extra[] extras) {
        this.extras = extras;
    }

    @JsonProperty("extras")
    public Extra[] getExtras() {
        return this.extras;
    }

    @JsonProperty("original_source")
    public void setOriginal_source(final String original_source) {
        this.original_source = original_source;
    }

    @JsonProperty("original_source")
    public String getOriginal_source() {
        return this.original_source;
    }

    @JsonProperty("license_url")
    public void setLicense_url(final String license_url) {
        this.license_url = license_url;
    }

    @JsonProperty("license_url")
    public String getLicense_url() {
        return this.license_url;
    }

    @JsonProperty("revision_id")
    public void setRevision_id(final String revision_id) {
        this.revision_id = revision_id;
    }

    @JsonProperty("revision_id")
    public String getRevision_id() {
        return this.revision_id;
    }

    @JsonProperty("identifier")
    public void setIdentifier(final String[] identifier) {
        this.identifier = identifier;
    }

    @JsonProperty("identifier")
    public String[] getIdentifier() {
        return this.identifier;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
